@@ -2,8 +2,20 @@ import os
 import subprocess
 import sys
 import time
+import logging
 from logging import error
 
+# Configure a logger for the service module
+logger = logging.getLogger("cornflow.service")
+logger.setLevel(logging.INFO)
+
+# Add console handler if not already present
+if not logger.handlers:
+    handler = logging.StreamHandler(sys.stdout)
+    formatter = logging.Formatter("%(asctime)s [%(name)s] [%(levelname)s] %(message)s")
+    handler.setFormatter(formatter)
+    logger.addHandler(handler)
+    logger.propagate = False
 
 import click
 from .utils import get_db_conn
@@ -89,9 +101,10 @@ def init_cornflow_service():
 
         external_app_lib = import_module(external_app_module)
         app = external_app_lib.create_wsgi_app(environment, cornflow_db_conn)
-
         with app.app_context():
+
             _initialize_database(app, external_app_module)
+
             _create_initial_users(
                 config["auth"],
                 config["cornflow_admin_user"],
@@ -101,6 +114,7 @@ def init_cornflow_service():
                 config["cornflow_service_email"],
                 config["cornflow_service_pwd"],
             )
+
             _sync_with_airflow(
                 config["airflow_url"],
                 config["airflow_user"],
@@ -117,6 +131,7 @@ def init_cornflow_service():
 
 def _setup_environment_variables():
     """Reads environment variables, sets defaults, and returns config values."""
+
     environment = os.getenv("FLASK_ENV", "development")
     os.environ["FLASK_ENV"] = environment
 
@@ -218,7 +233,7 @@ def _configure_logging(cornflow_logging):
             if logrotate.returncode != 0:
                 error(f"Error configuring logrotate: {logrotate.stderr}")
             else:
-                print(logrotate.stdout)
+                logger.info(logrotate.stdout)
         except Exception as e:
             error(f"Exception during logrotate configuration: {e}")
 
@@ -236,6 +251,7 @@ def _initialize_database(app, external_app_module=None):
 
         Migrate(app=app, db=db, directory=migrations_path)
         upgrade()
+        logger.info("----------------Migrations applied----------------")
         access_init_command(verbose=False)
 
 
@@ -285,14 +301,21 @@ def _sync_with_airflow(
 
 def _setup_external_app():
     """Performs setup steps specific to external applications."""
+
     os.chdir(MAIN_WD)
+
     if _register_key():
+
         prefix = "CUSTOM_SSH_"
         env_variables = {
             key: value for key, value in os.environ.items() if key.startswith(prefix)
         }
         for _, value in env_variables.items():
             _register_ssh_host(value)
+    else:
+        logger.info(
+            "************************ NO SSH KEY TO REGISTER ************************"
+        )
 
     # Install requirements for the external app
     pip_install_cmd = "$(command -v pip) install --user -r requirements.txt"
@@ -301,10 +324,15 @@ def _setup_external_app():
     if result.returncode != 0:
         error(f"Error installing requirements: {result.stderr}")
     else:
-        print(result.stdout)
+        logger.info(result.stdout)
     time.sleep(5)  # Consider if this sleep is truly necessary
     sys.path.append(MAIN_WD)
 
+    # Add .local path to sys.path so pip --user packages can be found
+    local_lib_path = os.path.expanduser("~/.local/lib/python3.12/site-packages")
+    if local_lib_path not in sys.path:
+        sys.path.insert(0, local_lib_path)
+
 
 def _start_application(external_application, environment, external_app_module=None):
     """Starts the Gunicorn server."""
@@ -349,4 +377,4 @@ def _register_key():
         os.system(add_key)
         return True
     else:
-        return False
+        return False
\ No newline at end of file
